==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-session/lxqt-session/lxqt-session_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <source>LXQt Session Crash Report</source>
        <translation>Resoconto di errori della sessione di LXQt</translation>
    </message>
    <message>
        <source>Application &apos;%1&apos; crashed too many times. Its autorestart has been disabled for current session.</source>
        <translation>L&apos;applicazione &apos;%1&apos; si è chiusa per errore troppe volte. Il suo riavvio automatico è stato disattivato per l&apos;attuale sessione.</translation>
    </message>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="289"/>
        <source>Crash Report</source>
        <translation>Rapporto di crash</translation>
    </message>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="290"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; è andato in crash troppe volte. Il suo avvio automatico è stato disabilitato fino al prossimo accesso.</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Benvenuto in LXQt</translation>
    </message>
    <message>
        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
&lt;p&gt;
Before starting to use the LXQt, you might want to select the Windows Manager:</source>
        <translation>&lt;b&gt;Benvenuto in LXQt&lt;/b&gt;
&lt;p&gt;
Prima di iniziare a usare LXQt dovresti selezionare il gestore delle finestre:</translation>
    </message>
    <message>
        <source>You can change the Window Manager later at any time via LXQt Session Configurator.</source>
        <translation>Puoi cambiare il gestore delle finestre quando vuoi tramite lo strumento di configurazione della sessione di LXQt.</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>Altro...</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>Scegli il tuo preferito.</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Benvenuto in LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Scegli il gestore delle finestre.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>È possibile cambiarlo in ogni momento da: Preferenze -&gt;Impostazioni della sessione -&gt; Impostazioni di base.</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-session/lxqt-session_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <source>LXQt Session Crash Report</source>
        <translation type="vanished">Resoconto di errori della sessione di LXQt</translation>
    </message>
    <message>
        <source>Application &apos;%1&apos; crashed too many times. Its autorestart has been disabled for current session.</source>
        <translation type="vanished">L&apos;applicazione &apos;%1&apos; si è chiusa per errore troppe volte. Il suo riavvio automatico è stato disattivato per l&apos;attuale sessione.</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="302"/>
        <source>Crash Report</source>
        <translation>Rapporto di crash</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="303"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; è andato in crash troppe volte. Il suo avvio automatico è stato disabilitato fino al prossimo accesso.</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Benvenuto in LXQt</translation>
    </message>
    <message>
        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
&lt;p&gt;
Before starting to use the LXQt, you might want to select the Windows Manager:</source>
        <translation type="vanished">&lt;b&gt;Benvenuto in LXQt&lt;/b&gt;
&lt;p&gt;
Prima di iniziare a usare LXQt dovresti selezionare il gestore delle finestre:</translation>
    </message>
    <message>
        <source>You can change the Window Manager later at any time via LXQt Session Configurator.</source>
        <translation type="vanished">Puoi cambiare il gestore delle finestre quando vuoi tramite lo strumento di configurazione della sessione di LXQt.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>Altro...</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>Scegli il tuo preferito.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Benvenuto in LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Scegli il gestore delle finestre.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>È possibile cambiarlo in ogni momento da: Preferenze -&gt;Impostazioni della sessione -&gt; Impostazioni di base.</translation>
    </message>
</context>
</TS>
